==> agr-center-domain-3.1.0-CLOUD-DEV-20230522.085240-33-sources.jar: com/tydic/dyc/agr/model/agrchange/IAgrChngApplyModel.java <==
package com.tydic.dyc.agr.model.agrchange; 

import com.tydic.dyc.agr.model.agrchange.AgrChngApplyDo;
import com.tydic.dyc.agr.model.agrchange.qrybo.AgrAgrChngApplyQryBo;
import com.tydic.dyc.agr.model.agrchange.qrybo.AgrItemChngListQryReqPageBo;
import com.tydic.dyc.agr.model.agrchange.qrybo.AgrItemChngListQryRspPageBo;
import com.tydic.dyc.agr.model.agrchange.qrybo.AgrAgrChngApplyListRspBO;

/**
 * 描述： 
 * 
 * @author auto_gen
 * @date 2023-04-23 19:08
 **/
public interface IAgrChngApplyModel {
	/**
	 * 协议主体变更申请新增方法
	 */
	 void createAgrMainChng(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议主体变更申请修改方法
	 */
	 void updateAgrMainChng(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议变更申请新增方法
	 */
	 void createAgrChngApply(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议变更申请修改方法
	 */
	 void updateAgrChngApply(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议明细变更删除方法
	 */
	 void deleteAgrItemChng(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议变更申请详情查询方法
	 */
	 AgrChngApplyDo getAgrChngApplyDetail(AgrAgrChngApplyQryBo agrAgrChngApplyQryBo);
	/**
	 * 协议主体变更详情查询方法
	 */
	 AgrChngApplyDo getAgrMainChngDetail(AgrAgrChngApplyQryBo agrAgrChngApplyQryBo);
	/**
	 * 协议明细变更新增方法
	 */
	 void saveAgrItemChng(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议明细变更列表查询方法
	 */
	 AgrItemChngListQryRspPageBo getAgrItemChngList(AgrItemChngListQryReqPageBo agrItemChngListQryReqPageBo);
	/**
	 * 协议变更申请主体修改方法
	 */
	 void updateAgrChngApplyMain(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议变更申请删除方法
	 */
	 void deleteChngApply(AgrChngApplyDo agrChngApplyDo);
	/**
	 * AGRF0048-协议变更申请主体列表查询
	 */
	 AgrAgrChngApplyListRspBO getAgrChngApplyList(AgrAgrChngApplyQryBo agrAgrChngApplyQryBo);
	/**
	 * AGRF0049-协议明细变更新增校验
	 */
	 void checkAgrChngItemSave(AgrChngApplyDo agrChngApplyDo);
	/**
	 * AGRF0050-修改协议明细变更指定字段
	 */
	 void updateAgrChngItemSpecifyField(AgrChngApplyDo agrChngApplyDo);

}

==> agr-center-domain-3.2.2-CLOUD-DEV-20241022.082438-3-sources.jar: com/tydic/dyc/agr/model/agrchange/IAgrChngApplyModel.java <==
package com.tydic.dyc.agr.model.agrchange; 

import com.tydic.dyc.agr.model.agrchange.AgrChngApplyDo;
import com.tydic.dyc.agr.model.agrchange.qrybo.AgrAgrChngApplyQryBo;
import com.tydic.dyc.agr.model.agrchange.qrybo.AgrItemChngListQryReqPageBo;
import com.tydic.dyc.agr.model.agrchange.qrybo.AgrItemChngListQryRspPageBo;
import com.tydic.dyc.agr.model.agrchange.qrybo.AgrAgrChngApplyListRspBO;
import com.tydic.dyc.agr.model.agrchange.qrybo.AgrAgrChngApplyListQryReqPageBo;
import com.tydic.dyc.agr.model.agrchange.qrybo.AgrAgrChngApplyListQryRspPageBo;

/**
 * 描述： 
 * 
 * @author auto_gen
 * @date 2023-08-04 16:18
 **/
public interface IAgrChngApplyModel {
	/**
	 * 协议主体变更申请新增方法
	 */
	 void createAgrMainChng(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议主体变更申请修改方法
	 */
	 void updateAgrMainChng(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议变更申请新增方法
	 */
	 void createAgrChngApply(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议变更申请修改方法
	 */
	 void updateAgrChngApply(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议明细变更删除方法
	 */
	 void deleteAgrItemChng(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议变更申请详情查询方法
	 */
	 AgrChngApplyDo getAgrChngApplyDetail(AgrAgrChngApplyQryBo agrAgrChngApplyQryBo);
	/**
	 * 协议主体变更详情查询方法
	 */
	 AgrChngApplyDo getAgrMainChngDetail(AgrAgrChngApplyQryBo agrAgrChngApplyQryBo);
	/**
	 * 协议明细变更新增方法
	 */
	 void saveAgrItemChng(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议明细变更列表查询方法
	 */
	 AgrItemChngListQryRspPageBo getAgrItemChngList(AgrItemChngListQryReqPageBo agrItemChngListQryReqPageBo);
	/**
	 * 协议变更申请主体修改方法
	 */
	 void updateAgrChngApplyMain(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议变更申请删除方法
	 */
	 void deleteChngApply(AgrChngApplyDo agrChngApplyDo);
	/**
	 * AGRF0048-协议变更申请主体列表查询
	 */
	 AgrAgrChngApplyListRspBO getAgrChngApplyList(AgrAgrChngApplyQryBo agrAgrChngApplyQryBo);
	/**
	 * AGRF0049-协议明细变更新增校验
	 */
	 void checkAgrChngItemSave(AgrChngApplyDo agrChngApplyDo);
	/**
	 * AGRF0050-修改协议明细变更指定字段
	 */
	 void updateAgrChngItemSpecifyField(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 变更申请分页查询方法
	 */
	 AgrAgrChngApplyListQryRspPageBo getAllChngByPage(AgrAgrChngApplyListQryReqPageBo agrAgrChngApplyListQryReqPageBo);

	AgrChngApplyDo getAgrMainChng(AgrAgrChngApplyQryBo agrAgrChngApplyQryBo);
}
